/*
 * Copyright (C) 2024 The Android Open Source Project
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

syntax = "proto2";

package android.os.statsd.packagemanager;

import "frameworks/proto_logging/stats/atoms.proto";
import "frameworks/proto_logging/stats/atom_field_options.proto";

option java_package = "com.android.os.packagemanager";
option java_multiple_files = true;

extend Atom {
  optional ComponentStateChangedReported component_state_changed_reported = 863
      [(module) = "framework"];
}

/**
 * Logs the status of the component is changed.
 */
message ComponentStateChangedReported {
  // The state of component.
  enum ComponentState {
    // This component is in its default state.
    COMPONENT_STATE_DEFAULT = 0;

    // This component has been explicitly enabled.
    COMPONENT_STATE_ENABLED = 1;

    // This component has been explicitly disabled.
    COMPONENT_STATE_DISABLED = 2;

    // The user has explicitly disabled the component.
    COMPONENT_STATE_DISABLED_USER = 3;

    // This component should be considered, until the
    // point where the user actually wants to use it.
    COMPONENT_STATE_DISABLED_UNTIL_USED = 4;
  }

  // The UID for which the application is active.
  optional int32 uid = 1 [(is_uid) = true];

  // The old state of component.
  optional ComponentState component_old_state = 2;

  // The new state of component.
  optional ComponentState component_new_state = 3;

  // True if it is a launcher component.
  optional bool is_launcher = 4;

  // True if it is for whole app. False if it is for a component.
  optional bool is_for_whole_app = 5;

  // The UID for which the application calls this method.
  optional int32 calling_uid = 6 [(is_uid) = true];
}
